==> jc-1.4.0.tar.gz: javax/print/attribute/standard/PrintQuality.h <==
// public class javax.print.attribute.standard.PrintQuality

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class a5efd9689d8d8f29 javax_print_attribute_standard_PrintQuality

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_PrintQuality_H_
#define _JC_javax_print_attribute_standard_PrintQuality_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_standard_PrintQuality$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_PrintQuality$sub_refs	_jc_javax_print_attribute_standard_PrintQuality$sub_refs;
typedef struct _jc_javax_print_attribute_standard_PrintQuality$sub_nonrefs	_jc_javax_print_attribute_standard_PrintQuality$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrintQuality$refs	_jc_javax_print_attribute_standard_PrintQuality$refs;
typedef struct _jc_javax_print_attribute_standard_PrintQuality$nonrefs	_jc_javax_print_attribute_standard_PrintQuality$nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrintQuality$object	_jc_javax_print_attribute_standard_PrintQuality$object;

typedef struct _jc_javax_print_attribute_standard_PrintQuality$fields_struct	_jc_javax_print_attribute_standard_PrintQuality$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_PrintQuality$vmethods	_jc_javax_print_attribute_standard_PrintQuality$vmethods;
typedef const struct _jc_javax_print_attribute_standard_PrintQuality$vtable	_jc_javax_print_attribute_standard_PrintQuality$vtable;
typedef const struct _jc_javax_print_attribute_standard_PrintQuality$vtype	_jc_javax_print_attribute_standard_PrintQuality$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_PrintQuality$fields_struct {
	struct _jc_javax_print_attribute_standard_PrintQuality$object	*DRAFT;
	struct _jc_javax_print_attribute_standard_PrintQuality$object	*HIGH;
	struct _jc_javax_print_attribute_standard_PrintQuality$object	*NORMAL;
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24PrintQuality;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_PrintQuality$fields_struct _jc_javax_print_attribute_standard_PrintQuality$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_PrintQuality$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_PrintQuality$object *, jint);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrintQuality$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_PrintQuality$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_PrintQuality$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_PrintQuality$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_PrintQuality$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_PrintQuality$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_PrintQuality$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrintQuality$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_PrintQuality$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_PrintQuality$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_PrintQuality$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_PrintQuality$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_PrintQuality$vmethods	javax_print_attribute_standard_PrintQuality;
};

// Vtype
struct _jc_javax_print_attribute_standard_PrintQuality$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_PrintQuality$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrintQuality$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrintQuality$refs {
    _jc_javax_print_attribute_standard_PrintQuality$sub_refs	javax_print_attribute_standard_PrintQuality;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrintQuality$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrintQuality$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_PrintQuality$sub_nonrefs	javax_print_attribute_standard_PrintQuality;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_PrintQuality$object {
	_jc_javax_print_attribute_standard_PrintQuality$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_PrintQuality$vtype	*vtype;
	_jc_javax_print_attribute_standard_PrintQuality$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_PrintQuality$vtype _jc_javax_print_attribute_standard_PrintQuality$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_PrintQuality, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_PrintQuality$class_object;

#endif	/* _JC_javax_print_attribute_standard_PrintQuality_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/PrintQuality.h <==
// public class javax.print.attribute.standard.PrintQuality

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class a5efd9689d8d8f29 javax_print_attribute_standard_PrintQuality

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_PrintQuality_H_
#define _JC_javax_print_attribute_standard_PrintQuality_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_standard_PrintQuality$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_PrintQuality$sub_refs	_jc_javax_print_attribute_standard_PrintQuality$sub_refs;
typedef struct _jc_javax_print_attribute_standard_PrintQuality$sub_nonrefs	_jc_javax_print_attribute_standard_PrintQuality$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrintQuality$refs	_jc_javax_print_attribute_standard_PrintQuality$refs;
typedef struct _jc_javax_print_attribute_standard_PrintQuality$nonrefs	_jc_javax_print_attribute_standard_PrintQuality$nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrintQuality$object	_jc_javax_print_attribute_standard_PrintQuality$object;

typedef struct _jc_javax_print_attribute_standard_PrintQuality$fields_struct	_jc_javax_print_attribute_standard_PrintQuality$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_PrintQuality$vmethods	_jc_javax_print_attribute_standard_PrintQuality$vmethods;
typedef const struct _jc_javax_print_attribute_standard_PrintQuality$vtable	_jc_javax_print_attribute_standard_PrintQuality$vtable;
typedef const struct _jc_javax_print_attribute_standard_PrintQuality$vtype	_jc_javax_print_attribute_standard_PrintQuality$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_PrintQuality$fields_struct {
	struct _jc_javax_print_attribute_standard_PrintQuality$object	*DRAFT;
	struct _jc_javax_print_attribute_standard_PrintQuality$object	*HIGH;
	struct _jc_javax_print_attribute_standard_PrintQuality$object	*NORMAL;
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24PrintQuality;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_PrintQuality$fields_struct _jc_javax_print_attribute_standard_PrintQuality$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_PrintQuality$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_PrintQuality$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrintQuality$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_PrintQuality$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_PrintQuality$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_PrintQuality$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_PrintQuality$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_PrintQuality$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_PrintQuality$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrintQuality$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_PrintQuality$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_PrintQuality$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_PrintQuality$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_PrintQuality$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_PrintQuality$vmethods	javax_print_attribute_standard_PrintQuality;
};

// Vtype
struct _jc_javax_print_attribute_standard_PrintQuality$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_PrintQuality$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrintQuality$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrintQuality$refs {
    _jc_javax_print_attribute_standard_PrintQuality$sub_refs	javax_print_attribute_standard_PrintQuality;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrintQuality$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrintQuality$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_PrintQuality$sub_nonrefs	javax_print_attribute_standard_PrintQuality;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_PrintQuality$object {
	_jc_javax_print_attribute_standard_PrintQuality$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_PrintQuality$vtype	*vtype;
	_jc_javax_print_attribute_standard_PrintQuality$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_PrintQuality$vtype _jc_javax_print_attribute_standard_PrintQuality$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_PrintQuality, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_PrintQuality$class_object;

#endif	/* _JC_javax_print_attribute_standard_PrintQuality_H_ */
